"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCurrentPage = exports.getIsDrawerOpen = exports.changePageName = exports.transitionTo = exports.toggleDrawer = undefined;

var _redux = require("redux");

// actionTypes
var TOGGLE_DRAWER = "TOGGLE_DRAWER";
var TRANSITION_TO = "TRANSITION_TO";
var id = "material-ui-redux-navigation";
// action creators
var toggleDrawer = exports.toggleDrawer = function toggleDrawer() {
  return {
    type: TOGGLE_DRAWER
  };
};
var transitionTo = exports.transitionTo = function transitionTo(feature) {
  return {
    type: TRANSITION_TO,
    feature: feature
  };
};
// reducer

// given state do a search through it to find a reducer with the id above
var findReducer = function findReducer(state) {
  var queue = [state];
  var seen = [];
  var currentNode;
  while (queue.length > 0) {
    currentNode = queue.pop();
    seen.push(currentNode);
    if (currentNode.reducerId && currentNode.reducerId == id) {
      return currentNode;
    }
    for (var key in currentNode) {
      // skip loop if the property is from prototype
      if (!currentNode.hasOwnProperty(key)) continue;

      var obj = currentNode[key];
      if (seen.indexOf(obj) == -1) {
        queue.push(obj);
      }
    }
  }
};
var changePageName = exports.changePageName = function changePageName(dispatch, pageName) {
  return dispatch(transitionTo(pageName));
};
var getIsDrawerOpen = exports.getIsDrawerOpen = function getIsDrawerOpen(state) {
  return findReducer(state).navigation.drawerOpen;
};
var getCurrentPage = exports.getCurrentPage = function getCurrentPage(state) {
  return findReducer(state).navigation.page;
};
var drawerOpen = function drawerOpen() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  var action = arguments[1];

  switch (action.type) {
    case TOGGLE_DRAWER:
      return !state;
    default:
      return state;
  }
};

var page = function page() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "dashboard";
  var action = arguments[1];

  switch (action.type) {
    case TRANSITION_TO:
      return action.feature;
    default:
      return state;
  }
};

var navigation = (0, _redux.combineReducers)({
  drawerOpen: drawerOpen,
  page: page
});
var reducerId = function reducerId() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : id;
  var action = arguments[1];

  return state;
};
var navigationId = (0, _redux.combineReducers)({
  navigation: navigation,
  reducerId: reducerId
});
//console.log(navigation);
exports.default = navigationId;